---
title: KG이니시스 상세 계약절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: KG이니시스 상세 계약절차
  description: >-
    KG이니시스의 전자결제 계약절차는 가입신청서 제출 - 계약안내 - 계약진행 - 계약완료 - 포트원 관리자콘솔 채널설정 - 개발진행 -
    카드사 심사 진행으로 이뤄집니다. 각 계약절차를 확인해보세요.
  keywords:
    - KG이니시스
    - 결제대행사 계약
tags:
  - KG이니시스
  - 결제대행사 계약
pgCompanies:
  - KG이니시스
searchTags:
  - 이니시스 계약절차
  - 이니시스
  - 이니시스사용방법
  - 이니시스이용절차
  - 이니시스가입절차
  - KG이니시스가입절차
  - KG이니시스계약절차
  - 이니시스계약
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="KG이니시스와 계약을 맺으시기 위한 절차를 순서대로 알려드립니다." />

### **가입신청서 제출**

[포트원 관리자콘솔↗](https://admin.portone.io/) 안에서 KG이니시스의 가입신청서를 제출합니다.

- 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) 회원가입 및 로그인 > 좌측 상단 \[전자결제 신청] 버튼 클릭 > 사업자등록증 업로드 > 원하는 결제수단 & 결제대행사 선택 후 제출

<Callout icon="" title="전자결제 신청방법 보러가기 ↗" />





### **KG이니시스의 계약 안내**

포트원으로 접수해 주신 신청건은 즉시 KG이니시스로 전달되며 가입 신청서를 제출해 주신 이후 2\~3영업일 내 KG이니시스 계약부서로부터 자세한 안내를 받습니다.

계약안내 메일은 모두 1번의 절차에서 적어주신 담당자님 메일 주소로 발송됩니다.(스팸함으로 종종 누락되기도 하니 스팸함까지 확인해 주세요)

### **계약진행**

메일 내용에 따라 필요한 구비서류 및 계약서 작성을 진행해 주세요.

결제대행사에서 요구하는 기본적인 구비서류는 아래를 통해 참고해 주시기 바라며 자세한 준비서류는 결재 대행사로부터 안내받으실 메일에 기재되어 있습니다.

<Callout title="계약 구비서류 보러가기 ↗" icon="" />

### **계약완료**

1. **KG이니시스 일반결제 이용시**

일반 결제의 경우 바로 오픈 서비스가 가능하므로 계약만 완료되면 발급된 MID는 즉시 사용이 가능합니다.\
단, 바로 오픈 특성상 할부,간편결제는 불가합니다.

바로 오픈 서비스로 일반 결제 먼저 이용하실 예정이시라면 5번의 단계로 바로 넘어가 주세요.

##### **2. KG이니시스 정기결제 및 간편결제 이용시**

정기결제와 간편결제 서비스는 바로오픈 서비스가 적용되지 않으므로 반드시 카드사 심사까지 완료된 후 사용이 가능하며, 이 전까지는 테스트 환경으로만 연동하실 수 있습니다.

<Callout content="KG이니시스는 계약 완료 시 담당자님 메일로 **키파일**이라는 압축파일을 제공합니다.
압축된 상태 그대로 해당 파일을 포트원 고객지원팀(cs@portone.io)으로 보내주세요!
미전달 시 일부 결제/환불에 오류가 발생될 수 있으니 유의해주시기 바랍니다" title="키파일 전달은 필수 !" icon=" 💡 " />

### **포트원 관리자콘솔 채널설정**

포트원 관리자콘솔에서 사용하실 PG사와 테스트용 MID를 설정합니다.

<Callout icon="" title="KG이니시스 채널설정방법 보러가기 ↗" />

### **개발진행**

포트원의 개발 연동 가이드를 참고하셔서 사이트 내 개발을 진행합니다.

심사를 받으실 사이트 내에서 결제 서비스 연동을 완료해 주셔야 하며, 모든 항목들이 최종 완성본 형태로 구현되어 있진 않아도 심사에 필요한 항목은 필수적으로 노출 · 동작되어야 합니다.

참고로 결제 이후 로직까지는 심사하지 않고 결제창이 정상적으로 노출되는지, 결제창 안에 카드사가 잘 노출되는지 등을 검수합니다.

<Callout title="서비스 필수 구축요건 보러가기 ↗" icon="" />

### **카드사 심사 진행**

최종적으로 카드사 심사를 진행하셔야 실 결제 서비스 사용이 가능합니다.\
(바로오픈 용 MID는 계약 완료 이후 바로 사용 가능하나 한 달 동안의 기한이 있습니다)

개발이 완료된 후 결제대행사(PG)로 카드사 심사를 요청하면, 결제대행사에서 각 카드사별로 심사를 요청하여 진행합니다. 카드사 심사는 각 카드사별로 진행되므로 완료일자가 정확하진 않으나 보통 2주 정도 소요됩니다.
